    %% Comparison of Planar Capacitors and Planar Inductors
    % We calculated valueas for a capacitor and an inductor.
    % Capacitive and inductive transducres are slightly different.
    % Capacitive transducer in MEMS should have area $\kappa = 1$ for the
    % medium.  
    %
    % I reproduced C, L, and R.  I may have misunderstood the argument
    % about the power, but I got slightly different results for $i_{max}$,
    % and $W_e$ and $r$.  In general, results are nearly the same.  
    %% Fundamentals constants in SI units
    %
    % $\epsilon_o = 8.854\times10^{-12} [F/m]; \mu_o =
    % 4\pi\times10^{-7} [H/m]$
    
    eps0 = 8.854e-12;  
    mu0 = 4*pi*1e-7;
    %% Planar capacitor
    % material properties and dimensions:
    %
    % $\kappa = 3; b = 1000 [\mu m];  A = b^2; g_c = 2 [\mu m]$
    %
    % Capacitance:
    %
    % $C = \kappa \epsilon  \frac{A}{g_c}$ 
    %
    kappa = 3; 
    b = 1e-3;
    A = b^2;
    gC = 2e-6;
    C = eps0*kappa*A/gC;
    % 
    fprintf('C = %3.2f [pF]\n',C_planar*1e12);
    
    
    %% Spiral Inductor
    % Material properties and dimensions:
    % Resistance $\rho = 1.7\times10^{-8} [\Omega m]$; relative permeability $\mu_r =
    % 1000$; number of turns $N=10$; coil size (effective inductance area)
    % $a = \frac{b}{\sqrt{2}}$; thickness of the insulating layer 
    % $g=1[\mu m]$; wire width $w = 20[\mu m]$; wire thickness $d=0.3
    % [\mu m]$; thickness of the magnetic layer $t = 0.3 [\mu m]$
    %
    % According to [Kawabe1984], the inductance and resistance are given by
    %
    % $L=\frac{\mu_o N^2
    % a^2}{\left(2+\frac{1}{(b/a)^2-1/2}\right)g+\frac{\sqrt{2}ab}{8\mu_r t}}$
    % 
    % $R = \frac{2\rho (N+1)a}{wd}$
    
    rho = 1.7e-8;
    mu_r = 1e3;
    N = 10;
    a = b/sqrt(2);
    g = 1e-6;
    w = 20e-6;
    d = 0.3e-6;
    t = 0.3e-6;
    L = mu0*N^2*a^2/( (2+1/((b/a)^2-.5))*g+sqrt(2)*a*b/8/mu_r/t);
    R = 2*rho*(N+1)*a/w/d;
    
    fprintf('L = %3.2f [nH]\tR=%3.2f [Ohm]\n',L*1e9,R);
    
    %% Scaled C, L, and R
    % $\alpha$ - dimensional scale
    %
    % $C(\alpha ) = \left(\kappa \epsilon_o \frac{A}{g_c}\right) \alpha$
    %
    % $L(\alpha)=\left(\frac{\mu_o N^2
    % a^2}{\left(2+\frac{1}{(b/a)^2-1/2}\right)g+\frac{\sqrt{2}ab}{8\mu t}}\right) \alpha$
    % 
    % $R(\alpha) = \left( \frac{2\rho (N+1)a}{wd} \right) \alpha$
    
    %% Voltage, current, power, and electric field
    % Assume $V_{max} = 3.5 V$ (not 3.3?) and assume power of 10 mW on 
    % $a^2 = 1 mm^2$ substrate. 
    %
    % $P_{max}(\alpha) = 10^{-2}\alpha^2$
    %
    % Current is given by 
    %
    % $i_{max}(\alpha) = \sqrt{\frac{P_{max}(a)}{R(a)}} = \left(0.1\sqrt{\frac{wd}{2\rho
    % (N+1)a} }\right)\sqrt{\alpha}$
    %
    % Maximum electric field
    %
    % $E_{max} = \frac{ V_{max} }{g_c}$ 
    %
    vMax = 3.5;
    Pmax = 10e-3;
    iMax = sqrt(Pmax/R); % nominal value
    Emax = Vmax/gC;
    
    fprintf('iMax/sqrt(alpha) = %3.2f [mA]\tEmax = %3.2f [kV/m]\n',iMax*1e3,Emax*1e-3)
    
    %% Energy and Energy Ratio:
    % $W_e(\alpha ) = \frac{1}{2}C(\alpha )v_{max}^2=\frac{\kappa \epsilon_o
    % Av_{max}^2}{2g_c}\alpha$
    %
    % $W_m(\alpha ) = \frac{1}{2}L(\alpha )*i^2_{max}(\alpha )= \frac{1}{2}\left(\frac{\mu_o N^2
    % a^2}{\left(2+\frac{1}{(b/a)^2-1/2}\right)g+\frac{\sqrt{2}ab}{8\mu
    % t}}\right)$ $\left(0.1\sqrt{\frac{wd}{2\rho
    % (N+1)a} }\right)^2 \alpha^2$
    %
    % $r(\alpha) = \frac{We(\alpha)}{Wm(\alpha)} \propto \frac{1}{ \alpha }$
    
    We = 1/2*C*vMax^2;
    Wm = 1/2*L*iMax^2;
    r  = We/Wm;
    fprintf('We = %3.2f [pJ]\t Wm = %3.2f [pJ] \t r = %e',We*1e12,Wm*1e12,r);
    alph = logspace(-1,1,50);
    loglog(alph, r./alph,'linewidth',2);
    set(gca,'fontsize',14);
    xlabel('Dimensional Scale \it\alpha');ylabel('Energy ration   \itr \rm(\it\alpha\rm)'); grid on;;
    %% References
    % [Kawabe1984] K. Kawabe , H. Koyoma, and K. Shirae, "Planar Inductor", IEEE TRANSACTIONS ON
    % MAGNETICS, VOL. MAG-20, NO. 5, SEPTEMBER 1984
